package storage

import "context"

// DefaultRepositoryStub provides noop stub instance for repository as well as statically ensuring interface compliance
var DefaultRepositoryStub Repository = StubRepository{}

// StubRepository provides noop repository implementation for use in tests
type StubRepository struct {
}

// Migrate stub
func (stub StubRepository) Migrate(ctx context.Context) error {
	return nil
}

// SessionRefresh stub
func (stub StubRepository) SessionRefresh(ctx context.Context, refreshToken string) (*SessionAuth, error) {
	return nil, nil
}

// SessionLogin stub
func (stub StubRepository) SessionLogin(ctx context.Context, user, password string) (*SessionAuth, error) {
	return nil, nil
}

// SessionIntrospect stub
func (stub StubRepository) SessionIntrospect(ctx context.Context, accessToken string) (*SessionIntrospection, error) {
	return nil, nil
}

// SessionImpersonate stub
func (stub StubRepository) SessionImpersonate(ctx context.Context, userID string) (*SessionAuth, error) {
	return nil, nil
}

// SessionRemove stub
func (stub StubRepository) SessionRemove(ctx context.Context, sessionID string) error {
	return nil
}

// SessionRemoveAll stub
func (stub StubRepository) SessionRemoveAll(ctx context.Context, userID string) error {
	return nil
}

// UserCreate stub
func (stub StubRepository) UserCreate(ctx context.Context, user *User) error {
	return nil
}

// UserUpdate stub
func (stub StubRepository) UserUpdate(ctx context.Context, user *User) error {
	return nil
}

// UserUpdateRoles stub
func (stub StubRepository) UserUpdateRoles(ctx context.Context, userID string, roles []*Role) error {
	return nil
}

// UserPasswordReset stub
func (stub StubRepository) UserPasswordReset(ctx context.Context, userID, password string) error {
	return nil
}

// UserGetByID stub
func (stub StubRepository) UserGetByID(ctx context.Context, userID string) (*User, error) {
	return nil, nil
}

// UserGetByEmail stub
func (stub StubRepository) UserGetByEmail(ctx context.Context, email string) ([]*User, error) {
	return nil, nil
}

// RoleGetByCode stub
func (stub StubRepository) RoleGetByCode(ctx context.Context, code string) (*Role, error) {
	return nil, nil
}
